==> kubernetes-model-autoscaling-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricSourceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ContainerResourceMetricSourceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceBuilder>{
  public ContainerResourceMetricSourceBuilder() {
    this(false);
  }
  public ContainerResourceMetricSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance) {
    this(fluent, instance, false);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContainer(instance.getContainer()); 
    fluent.withName(instance.getName()); 
    fluent.withTarget(instance.getTarget()); 
    this.validationEnabled = validationEnabled; 
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance) {
    this(instance,false);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContainer(instance.getContainer()); 
    this.withName(instance.getName()); 
    this.withTarget(instance.getTarget()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource build() {
    ContainerResourceMetricSource buildable = new ContainerResourceMetricSource(fluent.getContainer(),fluent.getName(),fluent.getTarget());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerResourceMetricSourceBuilder that = (ContainerResourceMetricSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-5.12.3-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricSourceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ContainerResourceMetricSourceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceBuilder>{
  public ContainerResourceMetricSourceBuilder() {
    this(false);
  }
  public ContainerResourceMetricSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ContainerResourceMetricSource(), validationEnabled);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance) {
    this(fluent, instance, false);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContainer(instance.getContainer()); 
    fluent.withName(instance.getName()); 
    fluent.withTarget(instance.getTarget()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance) {
    this(instance,false);
  }
  public ContainerResourceMetricSourceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContainer(instance.getContainer()); 
    this.withName(instance.getName()); 
    this.withTarget(instance.getTarget()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource build() {
    ContainerResourceMetricSource buildable = new ContainerResourceMetricSource(fluent.getContainer(),fluent.getName(),fluent.getTarget());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerResourceMetricSourceBuilder that = (ContainerResourceMetricSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
